( cd usr/doc ; rm -rf xv )
( cd usr/doc ; ln -sf /cdrom/usr/doc/xv xv )
( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
( cd usr/X11R6/bin ; rm -rf xv )
( cd usr/X11R6/bin ; ln -sf /cdrom/usr/X11R6/bin/xv xv )
( cd usr/X11R6/bin ; rm -rf bggen )
( cd usr/X11R6/bin ; ln -sf /cdrom/usr/X11R6/bin/bggen bggen )
( cd usr/X11R6/bin ; rm -rf vdcomp )
( cd usr/X11R6/bin ; ln -sf /cdrom/usr/X11R6/bin/vdcomp vdcomp )
( cd usr/X11R6/bin ; rm -rf xcmap )
( cd usr/X11R6/bin ; ln -sf /cdrom/usr/X11R6/bin/xcmap xcmap )
